pub struct ClaimUnstake {
pub user: Pubkey,
pub user_base_token: Pubkey,
pub user_restaking_account: Pubkey,
pub vault_account: Pubkey,
pub vault: Pubkey,
pub mint_account: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for ClaimUnstake.
Fields
user: Pubkeyuser_base_token: Pubkeyuser_restaking_account: Pubkeyvault_account: Pubkeyvault: Pubkeymint_account: Pubkeytoken_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for ClaimUnstakewhere
Pubkey: BorshSerialize,
impl BorshSerialize for ClaimUnstakewhere
Pubkey: BorshSerialize,
Sourceimpl IdlBuild for ClaimUnstake
impl IdlBuild for ClaimUnstake
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl ToAccountMetas for ClaimUnstake
impl ToAccountMetas for ClaimUnstake
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for ClaimUnstake
impl RefUnwindSafe for ClaimUnstake
impl Send for ClaimUnstake
impl Sync for ClaimUnstake
impl Unpin for ClaimUnstake
impl UnwindSafe for ClaimUnstake