pub struct GetUserData {
pub user: Pubkey,
pub user_restaking_account: Pubkey,
pub restaked_mint: Pubkey,
}Expand description
Generated client accounts for GetUserData.
Fields
user: Pubkeyuser_restaking_account: Pubkeyrestaked_mint: PubkeyTrait Implementations
Sourceimpl BorshSerialize for GetUserDatawhere
Pubkey: BorshSerialize,
impl BorshSerialize for GetUserDatawhere
Pubkey: BorshSerialize,
Sourceimpl IdlBuild for GetUserData
impl IdlBuild for GetUserData
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl ToAccountMetas for GetUserData
impl ToAccountMetas for GetUserData
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for GetUserData
impl RefUnwindSafe for GetUserData
impl Send for GetUserData
impl Sync for GetUserData
impl Unpin for GetUserData
impl UnwindSafe for GetUserData