pub struct InitializeVault {
pub authority: Pubkey,
pub vault_account: Pubkey,
pub vault: Pubkey,
pub token_mint: Pubkey,
pub system_program: Pubkey,
pub token_program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for InitializeVault.
Fields
vault_account: Pubkeyvault: Pubkeytoken_mint: Pubkeysystem_program: Pubkeytoken_program: Pubkeyrent: PubkeyTrait Implementations
Sourceimpl BorshSerialize for InitializeVaultwhere
Pubkey: BorshSerialize,
impl BorshSerialize for InitializeVaultwhere
Pubkey: BorshSerialize,
Sourceimpl IdlBuild for InitializeVault
impl IdlBuild for InitializeVault
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl ToAccountMetas for InitializeVault
impl ToAccountMetas for InitializeVault
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for InitializeVault
impl RefUnwindSafe for InitializeVault
impl Send for InitializeVault
impl Sync for InitializeVault
impl Unpin for InitializeVault
impl UnwindSafe for InitializeVault