pub struct OptInAvs {
pub operator_key: Pubkey,
pub operator_account: Pubkey,
pub avs_account: Pubkey,
pub operator_avs_registration: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for OptInAvs.
Fields
operator_key: Pubkeyoperator_account: Pubkeyavs_account: PubkeyThe AVS account - derived using AVS owner pubkey (same as RegisterAvs)
operator_avs_registration: PubkeyThe registration account linking operator to AVS
system_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for OptInAvswhere
Pubkey: BorshSerialize,
impl BorshSerialize for OptInAvswhere
Pubkey: BorshSerialize,
Sourceimpl IdlBuild for OptInAvs
impl IdlBuild for OptInAvs
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl ToAccountMetas for OptInAvs
impl ToAccountMetas for OptInAvs
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for OptInAvs
impl RefUnwindSafe for OptInAvs
impl Send for OptInAvs
impl Sync for OptInAvs
impl Unpin for OptInAvs
impl UnwindSafe for OptInAvs