pub struct Restake {
pub user: Pubkey,
pub user_base_token: Pubkey,
pub vault_account: Pubkey,
pub vault: Pubkey,
pub mint_account: Pubkey,
pub restaked_mint: Pubkey,
pub user_restaked_token: Pubkey,
pub user_restaking_account: Pubkey,
pub token_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for Restake.
Fields
user: Pubkeyuser_base_token: Pubkeyvault_account: Pubkeyvault: Pubkeymint_account: Pubkeyrestaked_mint: Pubkeyuser_restaked_token: Pubkeyuser_restaking_account: Pubkeytoken_program: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for Restakewhere
Pubkey: BorshSerialize,
impl BorshSerialize for Restakewhere
Pubkey: BorshSerialize,
Sourceimpl IdlBuild for Restake
impl IdlBuild for Restake
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl ToAccountMetas for Restake
impl ToAccountMetas for Restake
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for Restake
impl RefUnwindSafe for Restake
impl Send for Restake
impl Sync for Restake
impl Unpin for Restake
impl UnwindSafe for Restake