An Anchor generated module containing the program’s set of
instructions, where each method handler in the #[program] mod is
associated with a struct defining the input arguments to the
method. These should be used directly, when one wants to serialize
Anchor instruction data, for example, when speciying
instructions on a client.
Structs
- Claim
Rewards - Instruction.
- Claim
Unstake - Instruction.
- DeRegister
Avs - Instruction.
- DeRegister
Operator - Instruction.
- Initialize
Mint Account - Instruction.
- Initialize
Operator - Instruction.
- Initialize
Reward Treasury - Instruction.
- Initialize
State Account - Instruction.
- Initialize
Vault Account - Instruction.
- Operator
OptIn Avs - Instruction.
- Register
Avs - Instruction.
- Request
Unstake - Instruction.
- Restake
- Instruction.
- Slash
Operator - Instruction.
- Update
AvsMetadata - Instruction.
- Update
Operator Metadata - Instruction.