pub struct OperatorOptInAvs {
pub avs_owner: Pubkey,
}Expand description
Instruction.
Fields
avs_owner: PubkeyTrait Implementations
Sourceimpl BorshDeserialize for OperatorOptInAvswhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for OperatorOptInAvswhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for OperatorOptInAvswhere
Pubkey: BorshSerialize,
impl BorshSerialize for OperatorOptInAvswhere
Pubkey: BorshSerialize,
Sourceimpl Discriminator for OperatorOptInAvs
impl Discriminator for OperatorOptInAvs
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl IdlBuild for OperatorOptInAvs
impl IdlBuild for OperatorOptInAvs
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl InstructionData for OperatorOptInAvs
impl InstructionData for OperatorOptInAvs