pub struct RegisterAvs {
pub metadata: String,
pub registration_fee: u64,
}Expand description
Instruction.
Fields
metadata: Stringregistration_fee: u64Trait Implementations
Sourceimpl BorshDeserialize for RegisterAvs
impl BorshDeserialize for RegisterAvs
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for RegisterAvs
impl BorshSerialize for RegisterAvs
Sourceimpl Discriminator for RegisterAvs
impl Discriminator for RegisterAvs
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl IdlBuild for RegisterAvs
impl IdlBuild for RegisterAvs
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl InstructionData for RegisterAvs
impl InstructionData for RegisterAvs