pub struct OperatorAccount {
pub owner: Pubkey,
pub bond_amount: u64,
pub metadata: String,
pub active: bool,
pub avs_count: u32,
pub bump: u8,
pub vault_bump: u8,
}Fields
owner: Pubkeybond_amount: u64metadata: Stringactive: boolavs_count: u32bump: u8vault_bump: u8Trait Implementations
Sourceimpl AccountDeserialize for OperatorAccount
impl AccountDeserialize for OperatorAccount
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for OperatorAccount
impl AccountSerialize for OperatorAccount
Sourceimpl BorshDeserialize for OperatorAccount
impl BorshDeserialize for OperatorAccount
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for OperatorAccountwhere
Pubkey: BorshSerialize,
u64: BorshSerialize,
String: BorshSerialize,
bool: BorshSerialize,
u32: BorshSerialize,
u8: BorshSerialize,
impl BorshSerialize for OperatorAccountwhere
Pubkey: BorshSerialize,
u64: BorshSerialize,
String: BorshSerialize,
bool: BorshSerialize,
u32: BorshSerialize,
u8: BorshSerialize,
Sourceimpl Clone for OperatorAccount
impl Clone for OperatorAccount
Sourcefn clone(&self) -> OperatorAccount
fn clone(&self) -> OperatorAccount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperatorAccount
impl Debug for OperatorAccount
Sourceimpl Discriminator for OperatorAccount
impl Discriminator for OperatorAccount
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl IdlBuild for OperatorAccount
impl IdlBuild for OperatorAccount
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl Space for OperatorAccount
impl Space for OperatorAccount
const INIT_SPACE: usize = 151usize