pub struct StateAccount {
pub authority: Pubkey,
pub msol_mint: Pubkey,
pub jitosol_mint: Pubkey,
pub rm_sol_mint: Pubkey,
pub rjito_sol_mint: Pubkey,
pub bump: u8,
}Fields
msol_mint: Pubkeyjitosol_mint: Pubkeyrm_sol_mint: Pubkeyrjito_sol_mint: Pubkeybump: u8Trait Implementations
Sourceimpl AccountDeserialize for StateAccount
impl AccountDeserialize for StateAccount
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for StateAccount
impl AccountSerialize for StateAccount
Sourceimpl BorshDeserialize for StateAccount
impl BorshDeserialize for StateAccount
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for StateAccount
impl BorshSerialize for StateAccount
Sourceimpl Clone for StateAccount
impl Clone for StateAccount
Sourcefn clone(&self) -> StateAccount
fn clone(&self) -> StateAccount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StateAccount
impl Debug for StateAccount
Sourceimpl Discriminator for StateAccount
impl Discriminator for StateAccount
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl IdlBuild for StateAccount
impl IdlBuild for StateAccount
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl Space for StateAccount
impl Space for StateAccount
const INIT_SPACE: usize = 161usize