pub struct UserRestakingAccount {
pub user: Pubkey,
pub deposited_mint: Pubkey,
pub restaked_mint: Pubkey,
pub deposited_amount: u64,
pub restaked_amount: u64,
pub bump: u8,
pub cooldown_end_slot: u64,
pub pending_unstake: u64,
pub reward_debt: u64,
pub last_claimed_slot: u64,
}Fields
user: Pubkeydeposited_mint: Pubkeyrestaked_mint: Pubkeydeposited_amount: u64restaked_amount: u64bump: u8cooldown_end_slot: u64pending_unstake: u64reward_debt: u64last_claimed_slot: u64Trait Implementations
Sourceimpl AccountDeserialize for UserRestakingAccount
impl AccountDeserialize for UserRestakingAccount
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl BorshDeserialize for UserRestakingAccount
impl BorshDeserialize for UserRestakingAccount
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for UserRestakingAccount
impl Clone for UserRestakingAccount
Sourcefn clone(&self) -> UserRestakingAccount
fn clone(&self) -> UserRestakingAccount
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserRestakingAccount
impl Debug for UserRestakingAccount
Sourceimpl Discriminator for UserRestakingAccount
impl Discriminator for UserRestakingAccount
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl IdlBuild for UserRestakingAccount
impl IdlBuild for UserRestakingAccount
Sourcefn create_type() -> Option<IdlTypeDef>
fn create_type() -> Option<IdlTypeDef>
Create an IDL type definition for the type. Read more
Sourcefn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
fn insert_types(types: &mut BTreeMap<String, IdlTypeDef>)
Insert all types that are included in the current type definition to the given map.
Sourcefn get_full_path() -> String
fn get_full_path() -> String
Get the full module path of the type. Read more
Sourceimpl Space for UserRestakingAccount
impl Space for UserRestakingAccount
const INIT_SPACE: usize = 145usize